@@ -30,6 +30,15 @@ def m2m(db, table1, table2):
     )
 
 
+def _merge_mapper_args(cls):
+    classes = (cls,) + cls.__bases__
+    mapper_args = {}  
+    for c in classes:
+        if hasattr(c, '__mapper_args__'):
+            mapper_args.update(c.__mapper_args__)
+    return mapper_args
+
+
 class UUID(types.TypeDecorator):
 
     impl = types.String
@@ -49,12 +58,15 @@ class JoinedInheritanceMixin:
 
     @declared_attr
     def __mapper_args__(cls):
+        print('mapper_args from JoinedInheritanceMixin')
         indentity = cls.__name__.lower()
         mapper_args = {'polymorphic_identity': indentity}
 
         if JoinedInheritanceMixin in cls.__bases__:
             mapper_args.update({'polymorphic_on': cls._model_type})
 
+        mapper_args.update(_merge_mapper_args(cls))
+
         return mapper_args
 
 
@@ -75,16 +87,15 @@ class ModelUUID(SAModel):
     def created_at(cls):        
         return Column(DateTime, default=datetime.now, nullable=False, index=True)
 
-    @declared_attr.cascading
+    @declared_attr
     def __mapper_args__(cls):
+        print('mapper_args from ModelUUID')
+
         mapper_args = {
-            "order_by": cls.created_at
+            'order_by': cls.created_at
         }
 
-        classes = (cls,) + cls.__bases__
-        for c in classes:
-            if hasattr(c, '__mapper_args__'):
-                mapper_args.update(c.__mapper_args__)
+        mapper_args.update(_merge_mapper_args(cls))
         
         return mapper_args
 
